@@ -8,7 +8,7 @@ import lxml
 
 
 SAFE_EXTERNAL_LINK_PATTERNS = getattr(settings, 'SAFE_EXTERNAL_LINK_PATTERNS', ())
-safe_urls = ''
+safe_urls = '^$'
 if SAFE_EXTERNAL_LINK_PATTERNS:
     safe_urls = '(' + '|'.join(SAFE_EXTERNAL_LINK_PATTERNS) + ')'
 
@@ -26,6 +26,7 @@ class RewriteExternalLinksMiddleware(object):
 
             html = lxml.html.document_fromstring(response.content)
             for element, attribute, link, pos in html.iterlinks():
+                print element
                 # I only care about a tags with an href that is external
                 if element.tag == "a" and attribute == "href" and re.match(r'^http(s?):\/\/', link):
                     if re.match(safe_urls, link):
